#
# spec file for package DirectX-Headers
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           DirectX-Headers
Version:        1.610.0
Release:        150600.1.3
Summary:        DirectX Headers for Mesa
License:        MIT
URL:            https://github.com/microsoft/DirectX-Headers
# osc service runall download_files
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  meson
ExclusiveArch:  %{ix86} x86_64

%description
This package contains the official Direct3D 12 headers.
These headers are made available under the MIT license rather than the traditional Windows SDK license.
Additionally, this package hosts several helpers for using these headers.
Make sure that you visit the DirectX Landing Page for more resources for DirectX developers.

%prep
%autosetup

%build
%global _lto_cflags %{?_lto_cflags} -ffat-lto-objects
%meson -Dbuild-test=false
%meson_build

%install
%meson_install
%fdupes -s %{buildroot}

%files
%license LICENSE
%{_includedir}/directx
%{_includedir}/dxguids
%{_includedir}/wsl
%{_libdir}/pkgconfig/DirectX-Headers.pc
%{_libdir}/libDirectX-Guids.a
%{_libdir}/libd3dx12-format-properties.a

%changelog
* Fri Jun 16 2023 mpluskal@suse.com
- Install license
- Use -ffat-lto-objects for static libraries
* Thu Apr 13 2023 scott.bradnick@suse.com
- Update to 1.610.0:
  * This release matches the content provided in the DirectX12
    Agility SDK and the 1.610.0 NuGet package.
  - https://devblogs.microsoft.com/directx/directx12agility/
  - https://www.nuget.org/packages/Microsoft.Direct3D.D3D12/1.610.0
* Thu Mar 30 2023 scott.bradnick@suse.com
- Update to 1.608.2:
  * This release matches the content provided in the DirectX12
    Agility SDK and the 1.608.2 NuGet package.
  - https://devblogs.microsoft.com/directx/directx12agility/
  - https://www.nuget.org/packages/Microsoft.Direct3D.D3D12/1.608.2
* Mon Nov 21 2022 scott.bradnick@suse.com
- Update to 1.608.0:
  * This release matches the content provided in the DirectX12
    Agility SDK and the 1.608.0 NuGet package.
* Tue Aug 30 2022 scott.bradnick@suse.com
- Update to 1.606.4:
  * Update D3DX12.H to support new ABI for MinGW (#73)
  * dxguids: Add new GUIDs from the last several releases
* Tue Aug 16 2022 gmbr3@opensuse.org
- Update to 1.606.3:
  * Support Shader Model 6.7
* Wed May 25 2022 gmbr3@opensuse.org
- Clean spec file
  * Fix description
  * Use %%autosetup
  * Use meson macros
  * Use fdupes for duplicate files
  * Use a better URL
* Wed May 25 2022 sndirsch@suse.com
- added missing %%changelog section to specfile
* Wed May 25 2022 sndirsch@suse.com
- build exclusively on %%{ix86} x86_64, since DirectX ia only
  relevant on these platforms
* Wed May 25 2022 sndirsch@suse.com
- fixed 32bit build
* Thu May 12 2022 scott.bradnick@suse.com
- Renamed project/file references from 'directx-headers' to
  'DirectX-Headers' (as is upstream).
* Thu Apr 28 2022 scott.bradnick@suse.com
- Update to upstream version 1.600.10
* Thu Nov 11 2021 scott.bradnick@suse.com
  * Prepping for inclusion in X11:XOrg project:
  - General cleanup of .spec file
  - Adjusting to use proper naming of rpmlintrc.
  - Pre-0.57.0 version of 'meson install' does not support
    '--destdir', using ENV var for all but TW.
* Wed Aug 25 2021 scott.bradnick@suse.com
- Adding rpmlintrc for addFilter 'lto-no-text-in-archive'.
* Wed Aug 25 2021 scott.bradnick@suse.com
- Fixing file conflict for /usr/lib64/pkgconfig.
* Wed Aug 25 2021 scott.bradnick@suse.com
- Apparently pkgconf doesn't like /usr/local by default.
* Wed Aug 25 2021 scott.bradnick@suse.com
- Replacing hardcoded path in 'rm .../libDirectX-Guids.a' ...
* Wed Aug 25 2021 scott.bradnick@suse.com
- Seems to use /usr/local for generated .pc file vs. /usr
* Wed Aug 25 2021 scott.bradnick@suse.com
- Taking out 'libDirectX-Guids.a' and trying again.
* Wed Aug 25 2021 scott.bradnick@suse.com
- Trying to get 'libDirectX-Guids.a' added to resulting .rpm file.
* Wed Aug 25 2021 scott.bradnick@suse.com
- Some changes to get missing files added.
* Mon Aug 23 2021 scott.bradnick@suse.com
- Initial package version as 'directx-headers'.
